import { IGraphItem } from '../types';
/**
 * Preprocess text to remove links, emails, and other unwanted elements.
 * This ensures that irrelevant information does not affect similarity.
 *
 * @param {string} text - The input text to preprocess.
 * @returns {string} - The cleaned text.
 */
export declare const preprocessText: (text: string) => string;
/**
 * Sanitization & Stemming Function: Tokenizes, lowercases, stems, and preprocesses the input text.
 *
 * @param {string} text - The input string to sanitize, stem, and preprocess.
 * @returns {string[]} Array of sanitized and stemmed tokens.
 */
export declare const sanitizeAndStem: (text: string) => string[];
/**
 * Searches the provided graphs for a matching graph item based on the prompt.
 *
 * @param {string} [prompt=''] - The prompt string to search with.
 * @param {IGraphItem[]} graphs - List of graph items to search within.
 * @returns {IGraphItem | null} The best matching graph item, or null if no match is found.
 */
export declare const searchGraphByPrompt: (prompt: string | undefined, graphs: IGraphItem[]) => IGraphItem | null;
/**
 * Converts a snake_case string to camelCase.
 *
 * @param {string} str - The string to convert to camelCase.
 * @returns {string} The camelCase version of the input string.
 */
export declare const toCamelCase: (str: string) => string;
/**
 * Recursively converts all object keys to camelCase.
 *
 * @param {any} obj - The object or array to convert.
 * @returns {any} The object with keys converted to camelCase.
 */
export declare const convertKeysToCamelCase: (obj: any) => any;
