import { XpanderClient } from './XpanderClient';
import { ITool } from '../types';
/**
 * Interface representing tool instructions.
 */
interface IToolInstructions {
    /** The ID of the tool. */
    id: string;
    /** The description of the tool function. */
    function_description: string;
    /** The parameters for the tool. */
    parameters?: any;
}
/**
 * Creates a tool based on the provided client and tool instructions.
 * @param client - The XpanderClient instance.
 * @param toolInstructions - Instructions for creating the tool.
 * @param functionize - (Optional) Whether to include an invocation function for the tool. Default is true.
 * @returns The created Tool object.
 * @throws Will throw an error if the client object or its properties are not properly initialized.
 */
export declare function createTool(client: XpanderClient, toolInstructions: IToolInstructions, functionize?: boolean, getFunctionOnly?: boolean): ITool | any;
export {};
